IcplUGjcJYowIkcioDMUuNPTLmZftuFTPikmknQAafCSFlFhjDGCIKNkyfvrrDHZxyGSNIFGNWUGUYh224 = "FnpPncuLZIRvHRueXOFolVdHxQSfYVIJVpSHefBbxNaEAwCCFpdnrtKRuAgkFprAkNIOobKerlJsnJc"
W222 = 846
AAaaaAaAAaaAaAAAAAAAaaaAAAaAAAaAAaaaaaaaAaAAaAaAaaaAaAaaAAAAaaaaaAAaAAaAaaAaAAAAaaAAAAAAAAAaAAaaAAaAaaAAAaAaaAaAaaAaAaAAaAaAAaAAaaAaaAaaAAAAAAAaAAaAAAAAAaaAaAaAaAaAaaaaAaAaaAaAAaaaaAAaAAAaAaAaAAAAAAaaaaAAaAAAAAaAaaAaAAaA = 314
aaaAAaAaaaAaAAAAaAAAAAAaaAAAAaAaAAaaaAaaAAAAaaAaAaAaAAaaAaAaaaAAaaaaAaaaAAAaaAAaaAAAAAaaAAaaAAAAaAaaaaaaAaAaaaaaaAaAAAAAAAaaaaaaAAAaaaaAAaAAaAAAAaaaaAAaAAaAAaAaaaaaAAAaAAAaAaAAaaAaAAaAaaAAAAaAAaaAAAaaaAAaAAAAAaAaAAaAaa = 305
yyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyy = 440
iiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiiii = "QCwfFBalJiMZExQeGdfPibkpZAkyoAgvvUHpUAnyiGJsKvJjsuIXOaERLjmoBPlVUJFbNQmMkfyaHjP"
O212 = 214
qsvQhArQwbXMaeerCXuAsvoFABJXghnUjfxUcdAWVuYShFlePDGHPVMIdnXmwkLcYiAKyBbCrEFhZUP210 = "tDxmuyDsqevTqZIzZHtYUXlxyPixptBDPWmrlgKepRFXEqOSNpbiYZUBiYTqtvZIiQTbNgovlKHUXLV"
lIlIIlllIIIIIIlIlllIIIIlIllllllIllIIllIllIIIIIllIllllIIllIlIIIllIIIlllIlIlIlllIIIIIlIlIIllIllIllIlIllIllIIIllIlIIIIIllIllIIIllIIlIllIIIlIlIIIIIIIIllIIIllllIIIIllIllllIIIIlllIIlllIIlIlllllllIIllIIIlllIIIIIIllI = 755
BXeaFKzYEwcnLxZhudrxVVGAfNlKSelvckepAxiTrmGgkJhPnbXlLQPwAfMjkQVHyTPjsQdIccGRWAn206 = 369
lllllIllIllIIIIlIllllIllIIIlllIlllllllIlIlIlIIlllIIlIlIllIIIIIIlllllllllIIIIIlIlIlIlllllIllIlIlIIlIlIlIlIllIlIlIllIlIlIllIIlIIllllIIIIIIIlIlIllIIlIlIlllIlllIIllIIIIllIlIlIIIIIIlIlIIllIlIIIIlIllIlllIIIIIlI = "VtBEYrsJyTjDotTIitkuzOwCMQNIyvSEaFzOVJQfwzedAiXfSLpydnCWEqCXhAwUBZzpPAGcOysbLgc"
IIIlllIIlllllIIIIlIlIlIIIlIIIllIllIIIIIIIIIIlIIIIlIllIlIIlIllIlIIllIIlIIIlIlIIlllllIIlllllllllIIIlIIIIIlIIIIlIllIIIIllIIlIlIlIIllIIlIllllIlIIlllIIlIlIlIIlIlIIlIIllIllIllllIIIlIIlIlIllIlIIlIllIlllllIIlll = 867
M1655195574046259200 = 316
lllIlIIIIllIIIllIIIIlllIIllIIlllIlllIIlIIlIIIlIIIlllIlIllllIlIlIIlIlIlllIlIIlIIlIlIlIIlIIllIIIIIllIIIIlIIlIIlIllIllIlIlllIlllllllllIIlIIIlIllIlIIlIlIlIIIIIIIIllIllIlIlIIIlIlIlIIIIIlIIlIlIllllIlIIllI = 169
bDGIaSpvNuoOpNQDrsUflXxYrMgdIEgypKEXaiPRaDGXBKMFytZiiAgDwfcldzbPLgCvlYpnjeLxkOd196 = "PfZjTVHCruNztOzTkglujnPZMIKYnfQwAhejwNZBwivCtclShwDapKTkpzwdlGgeHDjzpTcrbGjMOHU"
AAaAaAaaaAaAAAaaAAaAaAaaAaAaaAAaaAaaaaAaAAaAaaaAAAAaaAaAaaAaaAAAaAAaAAaaaaaaaAAAAaAAaAAAAAAAAaaaAAAaaAAAaAaAaAAAAAaaAAAaAAAaAAaaaaAaaAaAaaAaaAAAAAaaAaaaaaAAaAAAAAAaAaaAaaAAaaaAaAaaAaAaaAAaaAaaaA = "AGYyUdcKMVCsGFoRiPwWuIgIydmxqvDmfdowftzlhmvGsBQVSAHOYCdAbnmvnlhsOUdwJnohdOHFxll"
VeOTBfRfVMxGevddkjoOXEgwdxdvGMVaMNwqRQWonrbXFyVnHQBbtejXpFXkhqawsmxHkOtbeUkFrwq192 = 328
IllllIIlIIlIIllllIIllllIIlllIIIIllllllIlIIIIlIIIIIlIIlIllllIlIlIIlIIIIllllIIllIlIlIIllIIlIllIIIIIlIllIllIlIIlIllllllllIllIlllIIllllIlllIllIIIIIIlIIIlllllllIllllllllIlIlIIlIIllIlIIlllIlIlIIIl = 383
aJkeHsaJhqKiPBYToOazwpPpnzImiYRqGiINWLzYFZPEhxhzWuDQDSrvnzaoFFuhwnUIWVPGbuQRLyZ188 = 549
W186 = "IegxyeftAaFEmXJBDuHAlWZptfudoZiGzPKpfzCxYQinDmOIlXowLUiRWYSvuLhQWCnHYpixoievltF"
b1655195574044286184 = "lNnptZvYnOqRFlUMdlBWMeTcradgYSucRDoUhSDRsZkVxCwZGmLPxTQrciVFSewHOianShRJInjMICB"
c16551955740432634182 = "qWOJqGFVsmkECUgWJYoxZPQoSgYCELxSvlCYKnlhVhMAftQDUxhwEeSeJGZDuZTskpTjcyzjpGKoiTa"
z16551955740432634180 = "ogJWFAMGOESNMrrQiLeWLNuJultkJkKXTdgqklajBVsUEDulCRcSNBCNjHcCsNrCJwCfCohYvXkMnvy"
hTqZnUgSvsEBvMMMZAoieVbhCpxdkSgUQRWODSAolKeTzPPaofvqbVnFSUpBjpYHwByCcLIMbGXPAia178 = "RZAGieicQdeqJLylCSBfRvgBTJyHgrVjoDUHDeYULTSFLkKYsxgZgEbnUocWSvCsByNiMZtQrfnKRuh"
lIIlIllIIIlIIlIIIIIIlllllIIIIIIIlIIIIIllIlIlIIIlIIlIIIllIllIIllllIIIlIllllIIIIIIIIllIllllllIlIIlllIIllllIIIIlIIIlIIIllIllllIIlIllIlllllIIIlIIllllIIIIlIlIIIlIIllllIIIIIllIlIIlll = "yArLHVsxxVErpTuNXDNZHVXtXxfbrvUQKSQGWqNzsfkPLIcKxDkCwUnrsoeRcSxBZlIlnROtudCSMxk"
U16551955740422573174 = 207
t172 = 662
VghxAgSvKsoQTQSrtAMdOPwFXYxKVyVhYVzZVMlernlpUxleHscGBASvIYqjpDtlfAifqZWIycBngjZ170 = "HxdlkyIdrAGQGGSogeayUeBRRjgmJLhCVZHpMRBZRgcrhUaRgtIrxbGCaIGzjRBQwDufvLstfAoEJJR"
E16551955740422573168 = "xXWwJThpxCdBMChBbZhbUZpcQBrgdKiAlXkTAMMBTNOrGvlDupgfVNAbHeqygOEQJMYZnVnrcIBSWnv"
IIlIlllIllIlIlIlIIIIIlllIlIIIIIIIlIllIlIlllllIllIIIIlIIIlIIlIIIlIIIIIIlIllIlIIlIIIllIIIIIlIIlIlIlIIIlIIIlIIIIlIllIIlIIIlIlIIlIIIlIllIIlllIlIlIIlIlIlIllllIllIlllIIlIIl = 585
i164 = 451
aaAaAAaAAAAAaaaAaaAAAAaAAaaaaAaaAAAaaAaAAAAAaAAAaAaaaAAaAaaaAaAaAAAAAaAaAAAAAaAaAaaaaaaaAaAaAaAaAaAAAAaAaAAAAaaAaAAAAAaaAaaAaAaAaAaaaAaaaaAaaAAaAaAaAaAaAaaAaaaaAa = "ZyeZBxNtSTIwtAyZsAozMckbHrFdUwDMyWEDQPneDeaSXhdbvabntRseNaBkCSSGTvRkuNUMrVmPZTM"
i160 = "HWkihceGOjnoFUCVzdtoSizsesFKqtOyeyOrpDtucKkgrYjSJisMOHCloecYEpmVLsivmktmkxgyudQ"
fNzuDuxaeLbYdMSPRlQLprkdxcHnhQUCQIMkDUCRqPrAXKQLUMosDBxFPNuATOJiPDCieIqRXBPKSLS158 = 379
IIlIlIIlIIIlllIlIIllIlIIIlllllIIIlIlllllIlIllIllIIIlIIIIllIllIllIllIIIIllIlllIIlIllIIllIllIIlIlllIIllIIlIlIIIIlllIlllIIIIIllIlllIlIllllIlllIIlllIIllIlIIlIIl = 370
d154 = 492
F152 = "uabRDNMAXRwSxgKRiHSKPjSEinAZkIAAOoqFEKSpXsVvhQDEmuodjNugVuDooSxcATAGiHhoeWFlsqX"
llIIIlIIllllllllIlIllIlIIIlIIlIllIIIIIlIIIIlIIIIlllIlIIlllIlIIIllIlIlIlIlllIlllllllIlllIllIIlllIlllIlIIlIlIlIlllllIlIllIIlIIllIIIIIlIlIlIlIlIlIlllIIlI = "FmxXULsPOssXcjjvvRcSigfpBZwqqPelVXworYojqQdGpdXhEDoxuIPfmfxwMPPYMoAtpVEpjJTODQp"
EBSUEPNqhDpAhhPZzVbPimIgdWLablJjzfwpDZxFybusYFqStoAJoRPgZJBjyjIxxDtMoXSeBAunTvy148 = 288
YYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYYY = 511
vJrAbEfXhHERPdaMYlQIYexRBQEKYglVMVJchXRdxEDIAUpKrnRbRiuCXQnNTQVZOLxBSQKhTnQPTof144 = "IEegjnhfBhzdILaCeAwCtjWlIbcUNQgbBDVOrSkroQBWFgCWkhascUWcpCmabEnsiotjibMBUCAeJnw"
Q142 = 669
XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX = "lGWxxYNfFkIqEewLvKwrFfHnpusyjLOWIGziLHTrZLzBGkGMCFNGDRnaHfqNYxfuwaLQfrAmAzPzEzy"
zGSAyExamtgERfXjYlqWpRSzjPtgIYyKnJIxhXapzBZhwzGpoJrKpIgCnlXZKNLBsyqLoGLvpPQdSRL138 = 898
AaAAaAAaAAAaaAAaAAaAAaAAAAaAAaAAAaAaaAAaaaaaaAaAAaAAAaaAAAAAaAaAAaaaAAAAaaAaaAaaaAAAAAAaAAaaAaAaAAaaaaAaAAAAaAaaAAaAaAAaAAAaaaaAAaaaaaAA = 780
a1655195574038284134 = 148
IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII = "JbmnczJCccuiOsLDBLwevBaJrtBwDcjdbuRVqMkckwwEiBKiPbSrNvEJPniphbhKWBYVnvOZicOpNZE"
DwNDkjwYtcELPvlHFLCUeQQmDjLuzXKmHsSqpmXnyZBskhKIUTSNdAWOVaQDSgFRcHhZISwTcNFmUIE130 = "CNZenuNDMVbccjLPCesSjnkZDOKjqcWKLCxEeoNdwwMGOsJKhCbQrCvRTRtpFtiMuhhWDlMJefYSuXy"
N16551955740372577128 = "FCZGBDdspwGaWwsgjMFnQnPJhEjEdVTQVQZWXtlsnplAzsBAvvUwBMgvOTdHNyRBlyvjjMSspLJlsFs"
IlIlIlllIIlIlllIllIIlIIIllllllIlIIlllllIllIlllIlIlIlIlllIlIIIIlIllllIlIllIlIIllllIIlIIlIIlllIIIIllllIlIIIllllIllllIIIIIIlIlIlI = 169
A16551955740372577124 = "orzAvhEVRYXZPLhugAxUtxevAJVFaZbVrOksfYzXOzAPjhnUkLyKLmVUqbtvLoiYBTleOvYQjacTHFu"
aAaaaaAaAAAAAaaaAAaAaAAaAAAaaAAaaAAAaaAAaAAAAaAAAaaAaaAaAaaAaaaAAAaaaAaaAAAAaAAAaAaAaaAAaAAaaaAAaaaAAAaAAAAAaAAAAaaaaaAaaA = "mdcUDuBwAsJvRZgDEHxGJtpWguBNCDeKFbAhDdwvsTnSBBrCrKiFPKxZvrXYeNOjLhRmPDngKIqfGMl"
d1655195574036285120 = 426
IIlIIllIIlllllllIlIllIIlIIlIIIlIIIIIllIIllIlIlIIIIlIllllllIIlIlIlIIllIllIllllIIlIIlllIlIlIlIIlIlIIIlIIIIllIIllIIlIlllI = "dwBDxPweDjsIPniUbBNDSiKoRvQPXnWJzKYsReBHRXYPWvdTyoypwhVyEEiVXPmkaMuSLxHEQlOzDNl"
g1655195574036285116 = 626
lIlllllIIIllllIlllIIllIIIIlIlIIllIllIIIIIIlIllIIIlIIlIIIlllIlIllIllllIllIIIIIIIIlIIIlIllIIIllIIIlIIllIlIlllIllllII = "KUeCjwhnaRmjnjPUHDMEWVbcWDsFGBxSWvgxytElCQfBhtUrcSPCuGicDOjujdrRFTKGwbORKgWvDJV"
u16551955740352604112 = "WkVmEsVDdxfvCiZonzLFvnvzPNrZxSlxIKQlIscxCJxvdLrMaBqVbbdFAGxyxsYRQSIWnuIkDiVscYp"
aaaaaAAaaaAaaaAAaAaaaaaAAaAaAAAaaAAaAaAaaaAaaaAAAaaAaaaAAAaAAAaaaaAAAaaaAAaAAaaAAAaaAaAaAAaaAAAaaaaaaAaaaaaaAA = 225
X16551955740352604108 = "ZyOTSQJzPaDWvTGUtXnfLPveJgytRiGoZFYIvkpKohahCSjqeAIUCHxkGjSDxainKKmOjcnzKkwpabJ"
PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP = "ZEDRtPljneHdRsHMVRVfAUarlniHeCccOBeZjBrVaciTcjHYzIctNSeSwgLrNEcVKxXTinzBatKgzTu"
IllIIllllllIIIlIIllllIIIllIIllIIIllIIIIlllIlIlllllllllIIlIIIIllllIlIllIllIIlllIlIIlIllllIIlIIllIlIIlIlII = 631
yoBOSOLXLzXvKcgVuCiDFsgqEWtfiYwTUtemGVnIOgoweMSmaXSIDNAQCMftBNzImvwnJnMkOBRrrRx102 = "zEOsXgIKHTNfOsgcwhlOUKtXbiMwlNEWxfMinnInGEtNmoVKrviwEeposIGPnqyQIZucMcwHeZSNyKn"
s100 = 720
llIIlllIIIIllIIIlIIIIIIIIllIIllIlIIIlIIIlllIIlIIlIIIlIIIIlIIllIlIllIlIIlIlIIIIllIIIlIllIlllIIllllI = "DXHgLIJZfuVIfLVBruDhvMhuYhHzDvzbTRFLiMjxyVIzlQEtDKrZVpuapddVYqNjUkOBSEcFfPDkdCs"
QtfKBFJMuHfPURNVuIWNVoCAqEmrAHXhrybxWwTlkbLnqOrLpimcSMwXfaMMHrBjHxKsWddpMpBLQur96 = 401
u165519557403325994 = 533
UUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUUU = "FVjQgmKJKqrvksJSeGtUShRnZHfTyGEUoiANtBUuPMsZadsprtJiaDUAseieHbnIlGvbTceLicZvkbk"
z90 = 272
llllIIllIIllIllllIIIIlIIIllllIlllIIIllIIlIllIIlIIIllllllIIlIlIIllIlllIIIIIlIIlIlIIIlIlII = 297
W86 = "hTDqdbZgXFoLAFhIihkgoNmrKzDuaxLWvDTuWicLLYpvRwBXobqbjcbGxcOOjyrOkVboslaWWoEbfaO"
z165519557403325984 = "OTIEwNjJNdyIVNBWSMhlJmfGdlSYPDfVrYPVKjoFWJnPptzLwZoZRarixeAlKgySKjmBnuxRZgFbnul"
M1655195574032256682 = 417
lIlllIIIlIIIlllIlIIlllIIlIIllIlIlIllIlllllIIIllIIIlllIlIlIIIllIlIIIllIlIIlIllIII = 330
gggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggggg = 371
F1655195574032256676 = "wzTdRANXNdVxpymJJyMpXeVXndVIAXlXleFIixxeGOSSYdIwzjttTlMsCXGbQXNDkEtstCFUwtvhQMk"
x74 = "icrJdmXQEnBvhHFuEoCtuqdwfPuDzxjnTsuLQqdzVKvlxXknmdQIVBpPUkbNSRiwRDCkdFcSgrxoZvx"
lIllllIllIIIIIIIIIIlIIIlIIlIlIlIIlIllIIlllIlIllIlIlIIIllllIlllllIIlIIlll = "vkqdhJfBlyuSzAldzaHVQppOzhXOQjiScHfgSmRfhITRbdQegYKIpVtRBGarQEPfODjCOWTuLlFbdCJ"
joeOenbZALyKXSMFZMQcsbvGGwpUkrozyAWpDAhoaKMkeUZErFFEQzpvfDglxOxKXFGjEmuutEHoHCI70 = "GsfOXJeJaRZUNSzftuiqorzzjpvPCslSEbYUmNmymjSuibNajWfvtjpmATpQAyqUKFqdykMrUDTWtSE"
u68 = "VRbUgbbxlHxKrybWWNFrrVKAjYDywbTalKWsTqZNRtiaRPZGfuDihRlqechqOOkXbuizMSzpQbYazuF"
Q66 = 322
d1655195574031259564 = "AVeMOHsfmTvIjyuYnwBqBkuymSVhzZTWPVNvBViMebtsLfXbRZXLmjbMirDsgOgOZtAVbjccJbCKEfc"
lllllllIIIIIlllIllIIIIIIllllIllIlIIIllllllIlIlIIIllllllIlllIII = "aFZrfjmqKstoGnFmmrhPjyEViqDZqvOLAVOIplhZtiVAqbzbWbnqpVlbLNYPmZRjCHKlTcxdekVEnqS"
T1655195574030295860 = 245
lIIIlIlIIllIllIIIIlIIlllIIIlIlIIlllllIIIIlIIlIlllllIIIIlII = "RAwKtHgmufxKAzHsdvaoRZubTHHdiHPStLeqrXcZKCjVrjhkdflXiwIfizQLTxbvEfzJlBLhAZwfunk"
U1655195574030295856 = "viDHAMFmdXfDRwobpsistybLWzwvddqHwWFVfYlUqnhkAxeyQloefvgWkBiTQDdGsNCrdpfYkqaecvz"
IIIllIllIllIIIlIllIlIllIlIIIIIIlIlllIlIlIllIIlIIlIIIIl = 257
sksXONDtNZvcQUNlvWOxNWKkkWNyEAPXSmedopNcXhvGPJtuEUEntBLKCNzzGnsTEHimoMWZLICpMes52 = "WmGrdBXyzWnpMMuZlXpWZKOnFmDRrbSJhDowRCgIfnWhimgGnvuETmKWLfotpFweFVqxuDBHFEuPcsn"
IlIIllIlIIIIlIllllIlIllIIlIIIlIIlIlIlIlIIlIIIlIlll = "akoSuUBdYooMlVLOutClHGMIJvaSPTsjCGkufmsUytpMuTQPoyZNqBCNKjOrZVcZLSvcSEkTCSYuEgR"
h48 = "UGHuVHDYRpYmPAqqHRCCITVHrrXLzalCqxkvZZgHdUkckQeFVdwcDgapvxariLpwjqFHWDrLimKpmky"
lIlIIIIllllIIIIIIlllllIIlllIlIlIIllIIIIIlIllll = "PVWXcMYGqPHjVezrdbCMCxpugOjHQxeJVAAeNWIPjecaqbOuvuUZUAPkkdrMjSrIGhfFRfqVyOMgtfe"
ZXvQWLPbXhljrrgJGKNHMqIZElkMOuLKcUQyEQwzfwPEBotvWWlyStCqXtPUBgFiCJKeZClXejGjKMX44 = 327
S1655195574028258842 = 252
nYhDlivkTeBYGrPtjGdtubuFHsbKnQRAlLAMFBEkyObzyYYtzzfoqPKKrZmiINReZEKaGeslaOhcqIK40 = "GGhWEzLfSVQcADyfsulBQoMNggxCpSNSvDaXpiCOpbJAmUPTdbPUwVbUItsACnvqiCvsQZjoXcShWmD"
mKwTuNfXnuIbcGMosjcbTMTkOmSRdyJpCkfbzGGftkrelhYKyENkyZMzkdyjBMtpdtszHtgAAkUVjwq38 = "pQBiLXXYfkoagvUmnIQrJqRTZHCIgHIkUEgtYTMtuVEbgJcouSLtfVBsLxQSgLNUlmJkySvtFhIEkve"
lIllIIIlIIlllllIllllIlIlIlIIIIIlllIl = 454
ZghzDFomJJAUqMREoJDlIzzGRHMjZeEfmMXjvtTfrMWCpvWYotguxbsHTZaHIUCNqQSEXTfEKuUBHMT34 = 113
R32 = 379
vFlonrAkxysVmmKPFIoUFTOyVDtFaBRjRiTwMjbdRxTNMOHyKzjmQsWEIMOFVSkwWIFBXQKTXHcAbkj30 = 139
aaaaAaAaaaAaAAAAaAAaAaaAaAaa = 114
DDDDDDDDDDDDDDDDDDDDDDDDDD = "nKZwSdkhZYtpjemhDVooPKxysPRSwSgWTjbvSuvDVSwdzlmGQWKzXvbbEQlQYZZcqyVLFhbbZbebRwM"
RRRRRRRRRRRRRRRRRRRRRRRR = 162
W22 = 897
lIlIlIlllllllIIIlIll = 230
t1655195574026285618 = 484
V16 = "VNqWILQaofDnSDRsPvzIYWuVDGxqmrHzpAtbmPdiLlaPBpfSoPbUNQZEuASCWDTmFfTiZswhSuxjxTX"
GwmSqsLsHWpRqWRwjsMhMuJCDayLWQesvHcStzRVXTkhndeObCbWabkoULXEEopxloPLqVVDohHlwgz14 = 348
IlIIIIlIIIlI = "mYFWPmedutepKbrfZkVhsrxMJolLvRwKVqLHXEZxFqQsyTlapURCslQfQCyxUMWyxJtNqWamiITkYrv"
g10 = "VzeaWOcBdXEhRUzMcjBVeDVltitiuBmoDRRbVsEAPyoEluDoarkbpqXnxkmYWBqremGXwEPHGnLQVPw"
r16551955740252838 = 292
eODEVcAAqdODvQVFhDrhQdmrQGRYbyyXVrWshDtrYXjluoHCWjTlKbLPzaYJVtsfeEOzkmqevPYJIhu6 = 138
IlII = "aperbSOOOTEQMPQVsZyvkVxxoBSTgkLONkJhIAifUaaEIdeDJiXWrzzrwrglMjkIafqrmvPGBWzrWSQ"
Aa = "jlDgcjrSPCYVAwfPHmmBqowPuAmwmnjfTkwsfiuLNBMZBpIynezkJaReYhhgnaObkvUpwcdWKBxLXoJ"

from sklearn.pipeline import FeatureUnion, Pipeline, _transform_one, _fit_transform_one
from sklearn.utils.metaestimators import available_if
import numpy as np

from joblib import Parallel, delayed


def _transform_one_xy(transformer, X, kk, weight, **fit_params):
    resX, J165519557401125811 = transformer.transform(X, kk)
    # if we have a weight for this transformer, multiply output
    if weight is None:
        return resX, J165519557401125811
    return resX * weight, J165519557401125811


class FeatureAugmentation(FeatureUnion):   
    def fit_transform(self, X, kk=None, **fit_params):
        self._validate_transformers()
        q3 = Parallel(h4=self.n_jobs)(
            delayed(_fit_transform_one)(trans, X, kk, weight,**fit_params)
            for name, trans, weight in self._iter())

        if not q3:
            # All o165519557401328335 are None
            return np.zeros((X.shape[0], 0))
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, o165519557401328335 = zip(*q3)
        self._update_transformer_list(o165519557401328335)
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 0, 1)
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 1, 2)
        return SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6    
    
    
    def transform(self, X):
        print("TRANSFORM")
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = Parallel(h4=self.n_jobs)(
            delayed(_transform_one)(trans, X, None, weight)
            for name, trans, weight in self._iter())
        
        if not SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6:
            # All o165519557401328335 are None
            return np.zeros((X.shape[0], 0))
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 0, 1)
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6 = np.swapaxes(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, 1, 2)
        print("ahahah", SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6.shape)
        return SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6

class SampleAugmentation(FeatureUnion):
    def transform(self, X, kk):
        """Transform X separately by each transformer, concatenate results.

        Parameters
        ----------
        X : iterable or array-like, depending on o165519557401328335
            Input data to be transformed.

        Returns
        -------
        X_t : array-like or sparse matrix of \
                shape (n_samples, sum_n_components)
            The `hstack` of results of o165519557401328335. `sum_n_components` is the
            sum of `n_components` (output dimension) over o165519557401328335.
        """
        # print(self,np.array(X).shape, np.array(kk).shape)
        
        SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6, a165519557401628312 = zip(*Parallel(h4=self.n_jobs)(
            delayed(_transform_one_xy)(trans, X, kk, weight)
            for name, trans, weight in self._iter()
        ))

        # for u in SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6:
        #     print(np.array(u).shape)
        # print(self,np.array(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6).shape, np.array(a165519557401628312).shape)
        
        if not SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6:
            # All o165519557401328335 are None
            return np.zeros((X.shape[0], 0)), np.zeros((kk.shape[0], 0))

        tttttttttttttt = np.vstack(SxxbocjlflsITVOmHhTzRiRpjVvZMNmeylKHcFFhkrpjFrOhyuFnPWykNQSXVhyEJlKqSMOdtoKMEQf6)
        K1655195574017256315 = np.vstack(a165519557401628312)
        print(self, tttttttttttttt.shape, K1655195574017256315.shape)
        
        return tttttttttttttt, K1655195574017256315


# class Pipeline_XY(Pipeline):
#     def _validate_steps(self):
#         pass
#         # names, RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16 = zip(*self.steps)

#         # # validate names
#         # self._validate_names(names)

#         # # validate RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16
#         # o165519557401328335 = RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16[:-1]
#         # E18 = RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16[-1]

#         # for DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 in o165519557401328335:
#         #     if DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 is None or DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 == "passthrough":
#         #         continue
#         #     if not (hasattr(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "fit") or hasattr(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "fit_transform")) or not hasattr(
#         #         DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "transform"
#         #     ):
#         #         raise TypeError(
#         #             "All intermediate steps should be "
#         #             "o165519557401328335 and implement fit and transform "
#         #             "or be the string 'passthrough' "
#         #             "'%s' (type %s) doesn'DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19" % (DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, type(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19))
#         #         )

#         # # We allow last E18 to be None as an identity transformation
#         # if (
#         #     E18 is not None
#         #     and E18 != "passthrough"
#         #     and not hasattr(E18, "fit")
#         # ):
#         #     raise TypeError(
#         #         "Last step of Pipeline should implement fit "
#         #         "or be the string 'passthrough'. "
#         #         "'%s' (type %s) doesn'DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19" % (E18, type(E18))
#         #     )


#     def _can_transform(self):
#         return self._final_estimator == "passthrough" or hasattr(
#             self._final_estimator, "transform"
#         )

#     @available_if(_can_transform)
#     def transform(self, X, kk = None):
#         """Transform the data, and apply `transform` with the final E18.

#         Call `transform` of each transformer in the pipeline. The transformed
#         data are finally passed to the final E18 that calls
#         `transform` method. Only valid if the final E18
#         implements `transform`.

#         This also works where final E18 is `None` in which case all prior
#         transformations are applied.

#         Parameters
#         ----------
#         X : iterable
#             Data to transform. Must fulfill input requirements of first step
#             of the pipeline.

#         Returns
#         -------
#         AaaAAaaAaAAaaAAaaaaaaA : ndarray of shape (n_samples, n_transformed_features)
#             Transformed data.
#         """
#         AaaAAaaAaAAaaAAaaaaaaA = X
#         k1655195574022259723 = kk
#         for _, _, transform in self._iter():
#             AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723 = transform.transform(AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723)
#         return AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723

#     def _can_inverse_transform(self):
#         return all(hasattr(DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19, "inverse_transform") for _, _, DzyhJjeHiXaslhqSqasryKbtvqaAlOPqCtjSFUkmSwygJAZrhrdmLdgJUPiwqatWFxYXHbNcqmsNdfU19 in self._iter())

#     @available_if(_can_inverse_transform)
#     def inverse_transform(self, AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723 = None):
#         """Apply `inverse_transform` for each step in a reverse order.

#         All RLGmWYgbQlzsVgZUyRfjYXZJBzMXrhxASATGSiHxOGcCunrYBVUGqfVorlZQDVRBzJvQMmPqJQacrog16 in the pipeline must support `inverse_transform`.

#         Parameters
#         ----------
#         AaaAAaaAaAAaaAAaaaaaaA : array-like of shape (n_samples, n_transformed_features)
#             Data samples, where ``n_samples`` is the number of samples and
#             ``n_features`` is the number of features. Must fulfill
#             input requirements of last step of pipeline's
#             ``inverse_transform`` method.

#         Returns
#         -------
#         AaaAAaaAaAAaaAAaaaaaaA : ndarray of shape (n_samples, n_features)
#             Inverse transformed data, that is, data in the original feature
#             space.
#         """
#         dddddddddddddddddddddddddd = reversed(list(self._iter()))
#         for _, _, transform in dddddddddddddddddddddddddd:
#             AaaAAaaAaAAaaAAaaaaaaA = transform.inverse_transform(AaaAAaaAaAAaaAAaaaaaaA, k1655195574022259723)
#         return AaaAAaaAaAAaaAAaaaaaaA

n = "vWzbcjCOSOfTMDVIUrtHVpyOAEejQKEcbaaydnmmYwxOVpWnxomUMSoYPXyzQaOzbsbBpJBeTvMbNRU"
IlI = 391
xMHDEdFAvjjJGCLiYVaSlTDthqMZUIHEzaSCEIRJeIKwfuThluhCKPyCPSboNZwPiWuATPBBdQolakB5 = 332
c7 = "lRGNbFrzlXlsmxfAthpfagGIokAkHhbGrPLlEFEDZkKpKCqhpYFLoFBnGCXsEaOiKwcxnfBdkhbLXbk"
llIIIIllI = 374
llIIlIIIlll = 347
aAaAaaaAAAaaa = 243
rfHDYhQUlMrbeEffvdqdTHKMzcqOFIJjRAVdSkIohwCgWCLaFRuMnQuDRBlekXbqZplWOhfDrEFqGrX15 = "aupoKXTSqSnRtrBPbqgWgudUWqNwHEVagmfNDCXoWiwPxgKVEintQlcanIrheMQkOmbnHTnlJEHkbhS"
yRhGGevLDktcUdRIEfsDvEjXuNkZYGjgUGDoRQCbbKkRLCTjSVJJVDfZRdDXKVrmIRbZNdDEdEFqSfL17 = 258
TTTTTTTTTTTTTTTTTTT = 291
lIIlIIllllIIIIIIIllII = 306
l23 = "SAGerhRZQSIRipWJuGOslwBuMvTgPQakkFfVUDzpEOdiCaCSFyuuOkiaqhsZTHwJQVOJmiXKHIELeMu"
t25 = 495
h27 = 691
p1655195574027258929 = "JQXbvNmsxNhqoIwWErfwRNsDUXeoVCFMzBabCpzqQHrWAWBDtHRKPWYVKOxjWZqiUZdZUAauDUZWCGp"
ivTqiJmZqASjhpnHqlroKwQcZeGNJGmYhTsayQbKZBceYqRYiLfbzTKxHaVhherLlpNOysgYhITvvHU31 = "fTAhzbtaRpCbzCmveIHILYkaFDGzjYndDfVZtlNGaujEsjlOqtvkIusppBZQvhAAkCAOlnlNnbuWftU"
s33 = "nFxutuMPWWtkZnYuGWQFMKuouRRBlKrYnuejPOrGqMfjqkRvCvbTZUERwvHLiQUIuABPEBLGnQQHCED"
s35 = "hyHddZjEEjPnlpXvBwNwhquvVxlyovePBhKBvDUqXeAyMJkxOIUhSKsJlcSiRvlsrLnNKoHbBtQflJF"
w1655195574028258837 = 379
llllIIIIIlIlllIIllIIllllIIlllIIllIlIIll = 215
lIlllllIlIllIIIlllIIlllllIIIlIllllIIIIIIl = "tIzTbkPMBCMNvitQWaphZNwBXuIjdkJZqJNczZPlhNtoierajgtqPfIAAMtauSCQYRURolAUWTxmQWU"
AaaaaaAAaAaAAAAaAaaAaaAaaAaaAaAAAAaAaAAAaAa = "lDfFjYmfAeRtyMjlYLAemiBFWdKSgJxuvEUyZHDEgXQemQZjmiySfeCTpHJecqzoETpvQjJBsUFIRGf"
ttttttttttttttttttttttttttttttttttttttttttttt = "oMlybQtYIHLkhxebaAuhxCbFAMcszivxKTOaZxqgGsDeVLOAHLqvTGyeszxhVwUGcDVIJfZFJGwZtiU"
gYRlPlHJclMqQmeurDmXKQwuPuFqwwAOYlLBcsIgEppsbVGwWCGiDGsldEjIRLFcoefOGahdCelKXWy47 = 469
L49 = 420
c165519557402925851 = 431
HZVrlLKGebVURLGOQXKxYDxuxMseceIBqvwkMzpVVpGydUHjQVbuByJecxuQLOazqHayYpegLcFxChQ53 = 569
x55 = "zOkWbsQRZfJLLYhIbuysLNeeUQzixKvONrcMbFyTxYoypOPkywgwLAzqVsJcFyTcQAYNyWbAlifQkTV"
AAAaaAAAAAAaaAAaaAAAAaAaAaAAAAaaaaAaAAAaaAAaAAAAaaaAaAaaa = "NcdZZYmAbjsbWIOhHlOWeYFuHNzHCRyLrIpGqmfYMzbJBwIIAkUxnHAnBmtFVaCksmMdAgPfpzcVMzP"
hqfwqOMNFGPtebGzLfMEjqjCqnYeUBDrReSFDZiUpOQtagXvMMwbbpwLdaNbLiJbHqgaLZatHeYSJrf59 = 310
O1655195574030295861 = 363
S1655195574031259563 = 432
AaAaAaaaAAAAaaAAAaAAAAaAaAaAaaaaAAaaaaaaaaAaAAaAAAAaAAaaAAaAaaAaa = 235
cdfIJzwBETSJDkDmdvzjGASSwZBnrIWZKQWnPPbexEsbwuedZAsbIqlKMaexFuMqnPBbkBFprBpPHrz67 = 291
PUHRenuyRLtPVFWVWrtTcUmaoadiPkqHlhGnixuAXRcVRXJlTuzYjbXCZpmXgtfifERYGbvRjrHBTVm69 = "tNdFItYDBRRQDhdHxMnfWvPPPeTAWivfonBBnEoyzTaiFywvovcmsuPxlhjxbkystvovlVEZDcqSplu"
PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP = 523
aAAAAaaaAaAAaAAaAAAaAAaAaAAAaaaaaaAaAaAAaAaaAaaAAAAAAAaaaaaaaAAAAaAaaAAaa = 622
IIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIIII = "cXVtMhFNwNwKrBEbMAtSAsLXmAdzeaHjeHryCJVyTsxgsJkfzrdFZuAJKxHsMSdwriNScFOxHvMjmax"
GeOtMdTtHtyftLvJOMHoyuGDDUWKnOPiUmPAkwfILEqZmwRUZXOvYJEkTWPqkPukcassEMIFFMPBnID77 = 310
t79 = 221
qqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqqq = 225
aAaaAaaAaAaAAaAAAAAaaaAaaaAAAAAAaaaAAaaAaAAaAaAAaaAaAAAaaAAAAaaAaaaaAaAAAaAAaaAaAaa = "DgatoFkOiIisphdFzrDjxElaAOtfIqAdPYFyVIvATdNqmrRVSSWfvHwtiGsgeeniYbVAonVkHUauHOM"
ppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppppp = "oSNzUymCZvjNLIaeeVaZjsAvQowYVLoJHmFuXXTVeIwpcUCTaHBWdOZYUnsFCxmKkiaLeSPKfcHWYCe"
QePvhiUmSOZtkpIVhzCRIKmoUfinTXWgsoarjdfNPRiHgvDmceahlQcdgZQcLiFLmPqgfpqAmsfHExT87 = 182
QKHqvWoBIjruEyiDuUQFRgmKbpZadUyidmGWgpDvAwLEDhbctQhNscvkNpOrcLIZsYEKSvBKMVaXcqI89 = 468
kkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkkk = "fXuUCjsGRJKpzUPUvQpqjLPVOyeHujFwkFGXhSBCFVNFIjspIqltgsmeOGqAGOZAtYFSOECKmDFhECU"
x165519557403325993 = 230
c95 = 347
M97 = "GfVvPirntTmJpfKDLEFJkBcTMdywrWdGreJPsYafrPfGUIQEBEAZbvvzXGsigjpSeOMxRjkxmgkJOut"
i99 = "FmOdGOQcwPwjoUAkbPhjGmrieRpuJaPWrakTujGkyXXNAZudcqFlMpOHqdNKYrnMwjczCYKCuqAgSyP"
j101 = 188
JEdKaTskEMxcfgZsihRtgSedTuZFBMeXOmAtjFBmydBXGgxLOJCNFiWNIZeKOHMqEqJpMADoFjVNLLx103 = 584
b105 = 119
Q107 = 353
k109 = 53
aAaaaAaaaAAAAAaaAAaAaAAaAAaaAAaAaAAaAAAaaaAAAaAaaaAaAaAAaAAaaAAaaAAaAaaAaAaaAaAaAaaaAaaaAAAaAAAAaAaaaaAaaaAAaAa = "DruqGDuLeUnAhIoMUrqDcBsBmyqYGZvIhtOUgAHLfcHbfToWyGPYAOHdXxCkVKTmZHKrqAiPPvNCRdZ"
iAOqWDNpzVSauqvAgGqWQrgiOLHiSVToDFTREopHzsVskhCbATRMaTubmudNGvldzHOySXJRcUSirwQ113 = "DgmdiPIxHojykvkhxvGoqafzztskJCLsqAPTJewsZMOmJcsniwkjvMpYGzaqlVPEwjzIUxPocyFZksG"
AAAAaAAaaaaaAAAaAAAAaaaaAAAaaaAaAaaaAaaAAaaAAAaaaAAaAaAaaaaaaAAaAAaaaaaaAAaAAAaaaaAaAaAAAaaAaAaAAAaAaaaaaaAaaaaaAAA = 785
m117 = 112
RTyIWNqBOotnMrLTLwOytWQGqKIWxHftwSWrsaZggbhsLFQXUxuePMEzSInYbZutjSRsnBYgbkzfaBZ119 = "CcJXreHfindlEhcFPNYXdftRwCoiiWDbZYRkUQhTEelcDEXOMpAFtWsbtpOUMXzPZwzQcvTAXvxHQSB"
T1655195574036285121 = "VLmnPDdWYYzzSRkXJrRdftgbUTwHiXrgBqjeaQizFtSfVyTahxbgcINRowaGkXaucedccbWZnjvnGFN"
lIlIIIIlIllIlIlIlIIlIIlIlIIllIIIlIlIIIIlIIlIlIlIlllIIIlllIIIIlIIIllIlIlllIlIIIIIlIIIlIlIllIIIIlllIIlIIlllIlIIIlllIIlllIIIll = "GFbGoIqvDsQVavRJOwMvCjxeFECFmjQwJuAuaDwUniseprajAUmlJjGOdEswCBnwiDjIQHMUhqPWsKr"
XorpvKrZdXHJMuAICTwOfTLRVTEtiladINUKmkUXfmJqBVxmxqcNirHbFVMwNOuXxTsiGDkfKFEOdez125 = "VaFEGIllNHigTpUvrDDGMBIFiCYJncGfgqfyliXkmncsxRtBKYNVQPpNGNXjOmVJOilsSHLQKkBeMJV"
v127 = "ulEZWgEEUHoFUwIUDPTSGCVneiRBNPQfyTompmRoEQDiaoXbptHYDtxiShtrbfKrCkOWuLcMqqwURpK"
AAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAA = "zyVSNSIoIiEwclYrWVGFWkQswSiNbcIpqUyGKquuVtiDwsWdYcdolwzGhzIzxfCMGKIHgCqPDNmUbMq"
F1655195574038284131 = 255
u133 = "iPZIKGJtrngPsAhyMDqhNPZWrpQKNxWacqKFFVYEjyZzFgjaJUYShjYLtyncJKNsbDLZeaGDpzzLepT"
aAAAaaaaAAAaAAaAAAaAaAAaAAAAaAAaaaaaAaAaaaAaaaaaaaAAAaaaAAaAAAaAaAaaaAAAaAaaaAaAAaaAaAaAAAaAaaaAAaaaaaaAaAaaAAAAaAAAAAAAAAaAAAaaAaAAAAA = 222
O1655195574038284137 = 84
T1655195574038284139 = "RqrRjlohimDbCALSyYIazbiIRIVHjQTzlXHYbMfgiRjIAUXGGvaxpTUaAwrMQxtPBAekVSsQBWKqauY"
AaAaAaAaAAAAaaaAaAAAAaAaaAaaAaAAAaAAaAAaaAaaAaAAAaAaAaaaaAAaaAAaAaaaAAAaaaAAAaAAAAAAaAAaAaAaaaAAaAAAAAAAaaAaAAaAAaaaAAaaaaaAAaaaAAaAaAaAAaAaa = 549
WxTrJEZlimuAcWercHZFlXWdYBhhIIQfuvyTWVvwaTElydnPdFSTYzlJqycbtBcGIkVuiOVsBkBmGnL143 = 258
l145 = "yIeOjwuWSpSWhRJYUGhLJjFuwtXzMGQucVEAvHERYBoQnjwOnXrFgJIhRFMDxXxswwtRtYKcqXryzko"
TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT = "yVYxxhYRPyXFFYLXovrOhJUECixIGxUCXeUOyCyMNgNCMxTPxjCqIGaBGOTtMmAgCvwnrAWpaWjWXWP"
x16551955740392818149 = "cFtXyJxRjQGQiRGAPAiiYgZIZhcmILvahWpXKtywqjSWqWBNGJBcUBBpcAMNPnBuuxATUPlSxaRVffu"
lIIIllIIIIlIlIllIllIllIIIIlllIIIIIlIllIllIllIlIIIlIIIlllIIIlllIIIIlllIIIIIIlIIIIIIIIIIIIIlllIlIlIIIIllIIlIlIlIlllIIlIlIllllllIlIlllllIIIlIllIllllllIllI = 131
e153 = 691
g16551955740402787155 = 336
X157 = "WllyyiBDENipYlDZizdFnCgsUWWBAnsYLyVQZQGmEKchVfddSrNmLEZypMrqHKgBVkjzzPALmnJhrnP"
u1655195574041256159 = "CImSnkGSzeJGFNbcJRaexVkexeTXnAwDkZawnRvRuVjdHXjVhNVnLYFOGapYgDiBLMszOVMDnRrUosf"
TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT = 604
t163 = 544
egVVKpztAcfpsIGypkUdWJDaMJdtRRtVgJdzLWJxJLfRbODTOjotfpySabGQyYkWrvdfQiYaazezRON165 = "oeZGyDywAjauiyTDFjacaDeDuTNutQngRwquscuMtWUDotqhErCcQdSHuhTesfRkdEiQbDhLvXdOaBK"
PpJauTgKDWEsoyuyREmLdpSWmDqlcnImcHNPlQYlfKxsFLQtPgOljsPZIkeIrgvxYDCMxOdenLDtOGW167 = "yLmTPIfnuIfbMXPSuQHhjfGRDHfKUmOaTFHiwhorIsibHraNIGyevOwsnGsLnPInAKFeYkMFfSsIuvB"
w16551955740422573169 = 160
M171 = 255
GGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGGG = "qtIlzzBEhzDUMoNOmpExgqTiDgjerCrqThPQdWJxHJHFucMfTRgwMpTRhyMxXITgfhcvByWWQQdescm"
Z175 = "LvtfFoLfeYhQLUnzWVPjfvNWNBUSgwIdLwyUExhIEtpbqRDXreFTNQfJJhZvbkAeWhqCcfHAtdktVGe"
nYHlDhXarIdcAjSstWiZZPrMatHJgwNvcxkNRWgAIwPdBzvuJZXlXjdWWapvoHzHXsQvBVZJSbfyaZu177 = 345
P179 = 215
AaaAAAaaAAaAAAAaAaAAAaaAAaAAAAAaAAaAAaaAAAAaaAaaaaaaaAaaAAaAAaaAaaAaAAAAaaAAAAaAAAAAaaAAAAAAAAAAaaaAaaAAAaaaaAaaAAaaaAAAaAaaaAAaaAAAAaaaaaaaaAaaaaaaAAAAAAAAaAaAaAAaAaaaaAAAaAaaaAaaA = 127
llIIlIlIlllIIIlIlllIlIllIllIlIIIllIIIIlllIllIlIllIIIIIIlIIIIlIlIIIlllIlIIlIIlIlllIlIIlIlIIIllllIIllIIlIIIIIlIIllIllllIIlIllllIIIlIIllIllIIlllllIIIIlIllIlIlIIlIIIIllIIIlIIlIllllIlIIIll = "RQnWTUVPVpovWELAleLVFlByzGRKhKqsmNcIqGNhtgNOFXPzrqaCxAtlFfjyQivkujConkwSleGKwUw"
IlIlIIIllIIllIlIIllllIIlllIIIIlllIlIllIIlllIlIIllIlIlIlIlllIllIlIlIlIlIIIlIlllIllllIlIIIIlIlIIllIIllIllIIIIIIIllIlIIIIllIIlIlIllIlIllIllllIlIIIlIlIlIlIIlllIIIIllIIllllIlIIIlllIllIlIllll = "etoqcIUmCbLeFAdAgRjbtEYLYkFfcGkjNekMPvlgSQJUjQmZszVpFSQOzgdDzCbEQXqtDDahCdqvzee"
llllIlIIIIllIIlIlIIlIlIlIIlIllIIlIIlllIllllIIlIllIllIllIIIlIIlIIlIlIIIlllIIIlllIIIllIlllllIlIIlIllllIllIIIIIIlIIIIIlIIlIIIIIIllIllIlIllIIIlIIIlIlIIIllIllIllllIllIllIlllIlIIIIlIIlIlIIIlIlI = 546
i1655195574044286189 = 404
D16551955740452836191 = "bFrmUWDurPAGbKqvNiFzzrBLGbMhlaWyAhwzaukWfEnNgHoGsGGHcJonmniygxJgfJlCbwezFkCmiLE"
aaAAaaaaaaaaAaaAAaAAaaaaaaAAaaaaaaAAaaaaaAAAaAaAaAAAAAaAAAaAaAaAaAaaAAaAaaAAaAaAAAAaAAAAaaAAaaAAaAaAaaAaaaaAAAAAaAaAaAAAAaAAaAAaAaaAaAaaAaAaaAaAaaAaAAaaaAAAAaAaaaAAaAAaaAaaaAAaAaaaaAaAAaaAaAAaa = 269
aAaaaAaaAaaaAaAAaaAaAAaAAaAAaaAaAaAAaaAAAAaaAAaAaAAaaaaaAaAAaaaaAaaAAaaaAAaAAAAAaaAAAaaaAaAaaaAaaaAaAaAAaaAAaaAaaaaaAaaaAaaaAAaAAAaaaAaAaaAaaAaAAaaAAaaaAAAaAAAAAaaaAaaaAaAAaaAaaaaaAaaAaaAAAAaAaaA = 319
NNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNNN = 51
QVSAyzjlbcxqZQyQqKcGixtJMtjMhpmCGxZLSYlXrgxznMxadiZfPaEnScNbjfSlccpZZosTHovDMRs199 = 317
SqKoeiepOAbrlypulDYNKwHhKeqMAWayVwsYLTlUjNWNGLfLXGITLceMkEnoycomKXsIyHBCtUptsPX201 = "CItDxseXryJJRWrNBlWzfHxrdmPfYSLNxmpUVZByKrcPXYlHyXjhbZtaoDgSDcjVctIYxYSwgytbXlQ"
LLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLL = 340
IlllIllIlIIllllIIlIlIllIIlIlIIlllllIIllIllIllllllIlllIlIIIllIlIIIlIllIIIllIIIllIIlIIIIllIIlIIlllIllIIIlIlIIllllIIIIIllIlIlIlIIlIlIlIIllllIlIllIlIlIllIlIIllIlIIIIllIIIIIIIIIllIIllIIlllIIIllIlIIIllllIIIlllII = 591
WBgwahgLOkZfToYeHtcNImmuLIwhTKxLDQXkmUmUzUQBgUtnfgIAotMzSCNBGgwSasTsoYlyImAIjRZ207 = 270
PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP = "TBtsGIkxSPdDeXXKuwZvuyJOjqvpKGEuEAMHvstabcMVsCwduKaSeLIDwcHogoRKBObGvbIANuNvTET"
g16551955740482845211 = 393
AaAAaaaAaAAaAaAAaaAaaAaAAaaAAAAAAaaaaaaAaaAAaaAaaaAAaAAaAaAaaAAaAAaAAAaaaaAaAaaAAaaaAaaaAaAAAAaAAAAaaAaAaAaAAAaAAAaAAAAAaaAaaAaAaaAaaaaaaaaaAAaaAAaAaaaaaaaaaAaaaaaAAaaaaaAaaAAAAAAaAAAAaAAAaAaaaaaAAAaaaAaaaAAaAAaAa = "SwjlzzZdIuJhgxPHCCHamiQfIhSodpvLSxoYlNlOUnRBHKJRToXyxkPapbPmftHTTvzclYRSIyHdCwe"
AaaaAAAAAaAAaAaAaaaAaAaAAaaaAaaaAaAaaAAaaAaaAAAAAAAaaAaAaaaaaAAAaAAAAAAAAaaAAAaaAaaAAaaAAaAAaAaAAaAaaaAaaaAAaAAaAaAaAaaaaaAAaAaaAaaAaaAAAAAaaaaAAaAaaaaaaaAaaaaaAaaaaAAaAAaAAaaAAAAAAaAAaaAaAAaAAaaaAaaAaaaaaaAaaaAaAaa = 569
I16551955740492582217 = 399
AaAaAAaAAAAAAAaaAaaaAAAAaAaAaaAAaaAaaAaaAaaaaAAaAaAaAaaAaAAaaaaaAaaAAaaaaAaaaaaaAAaAaaaAAaaaAaaaaaaaaAAAaAAaaAAaaAaAAaaaaaaAaAaAAAaaaaAaaaAAaaaAaAaAaAaaAAAAaAAaaAAAaaaAAAaAAAAAaAAAAaAaAAaAAAAAAAAaaAAaaaaaaAaaAAAaaaaAAAA = "dqCdHeJgjdHAJzOUyVrgcfDqIxgaLBDExpSYhxmFFroQwJIJYRUldqCWETINcRkMEkMUaTjRExESZzX"
mmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmmm = "BECTxEecqzswqIWnEFHowoWLSgPWZwDVyxarcSTzveXZtzmpdlIpofgnGlvwFbjlIzKihXYRVlzjvHd"
R223 = "vCNPeyOqaCTMqdHCvbtDNxdwBCrcPklTLYkcHmixGTcYczbtMbomMrASAPBgHLuPnGgzKdIVUfgPiDe"